@@ -40,6 +40,7 @@ class Argument:
 def exec_ui(
         kind: Kind = Kind.BUTTON,
         description: str = None,
+        display_name: str = None,
         input_request: Tuple[str, ...] = ("Continue [Y/n]", "Abort [Y/n]"),
         use_kernel: bool = False,
         use_gui_app: bool = False,
@@ -69,6 +70,7 @@ def exec_ui(
             return response
         wrapper.__ui_kind__ = kind
         wrapper.__ui_description__ = description
+        wrapper.__ui_display_name__ = display_name
         wrapper.__ui_file__ = func.__code__.co_filename
         wrapper.__ui_module__ = func.__module__
         wrapper.__ui_input_request__ = input_request
@@ -159,6 +161,19 @@ def find_modules(module_path: str) -> Dict[str, Any]:
     }
 
 
+def get_script_module(script_location: str, exec_module: bool = True) -> Dict[str, Any]:
+    script_path = Path(script_location).resolve()
+
+    loader = importlib.machinery.SourceFileLoader(script_path.stem, str(script_path))
+    spec = importlib.util.spec_from_loader(script_path.stem, loader)
+    script = importlib.util.module_from_spec(spec)
+
+    if exec_module:
+        loader.exec_module(script)
+
+    return {script_path.stem: script}
+
+
 # Why I use my own class Arguments instead of just inspect.Parameter?
 # * because I don't want to be dependent on inspect.Parameter.empty in my apps
 # * because Argument might get more info from the exec_ui decorator, like e.g. units
